@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.130000';
+$BalanceOfPower::Commands::VERSION = '0.131000';
 use v5.10;
 use Moo;
 use IO::Prompter;
@@ -252,6 +252,11 @@ COMMANDS
         print $self->world->print_hotspots();
         $result = { status => 1 };
     }
+    elsif($query eq "war history")
+    {
+        print $self->world->print_war_history();
+        $result = { status => 1 };
+    }
 
     elsif($query =~ /^situation( (.*))?$/)
     {
