@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation::Role::IA;
-$BalanceOfPower::Nation::Role::IA::VERSION = '0.130000';
+$BalanceOfPower::Nation::Role::IA::VERSION = '0.131000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -66,7 +66,8 @@ sub domestic_advisor
     my $self = shift;
     return $self->advisor("LOWER DISORDER", 
                           "BOOST PRODUCTION",
-                          "TREATY NAG WITH");
+                          "TREATY NAG WITH",
+                          "DIPLOMATIC PRESSURE ON");
 }
 
 sub economy_advisor
@@ -78,13 +79,6 @@ sub economy_advisor
                           "ECONOMIC AID");
 }
 
-### MILITARY ###
-# Orders:
-#   DECLARE WAR TO
-#   MILITARY SUPPORT
-#   RECALL MILITARY SUPPORT
-#   BUILD TROOPS
-#   AID INSURGENTS
 sub military_advisor
 {
     my $self = shift;
@@ -109,7 +103,10 @@ sub good_prey
     my $self = shift;
     my $enemy = shift;
     my $world = shift;
-    my $level = shift;
+
+    my $crisis = $world->crisis_exists($self->name, $enemy->name);
+    my $level = $crisis ? $crisis->get_crisis_level : ALLY_CONFLICT_LEVEL_FOR_INVOLVEMENT;
+
     if($self->army < MIN_ARMY_FOR_WAR)
     {
         return 0;
@@ -172,7 +169,6 @@ sub good_prey
     {
         $war_points += 1;
     }
-
     if($war_points + $level >= 4)
     {
         return 1;
