@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.130000';
+$BalanceOfPower::Role::Analyst::VERSION = '0.131000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -128,12 +128,16 @@ sub print_borders_analysis
             $out .= as_subtitle("  Military support in the country:\n");
             my $supporter = $supps->start($b);
             my $sup_rel = $self->diplomacy_exists($nation, $supporter);
-            $out .= "    $supporter (" . $sup_rel->print_status();
-            if($sup_rel->is_crisis())
+            if($sup_rel)
             {
-                $out .= " " . $sup_rel->print_crisis_bar;
-            } 
-            $out .= ")\n";
+                $out .= "    $supporter (" . $sup_rel->print_status();
+                if($sup_rel->is_crisis())
+                {
+                    $out .= " " . $sup_rel->print_crisis_bar;
+                } 
+                $out .= ")";
+            }
+            $out .= "\n";
         }
     }
     return $out;
@@ -238,4 +242,17 @@ sub print_civil_war_report
     $out .= "Rebel support: " . $rebsup->print . "\n" if ($rebsup);
     return $out;
 }
+
+sub print_war_history
+{
+    my $self = shift;
+    my $out .= as_title("WAR HISTORY\n\n");
+    foreach my $w (@{$self->memorial})
+    {
+        $out .= $w->print_history;
+        $out .= "\n";
+    }
+    return $out;
+
+}
 1;
